@@ -1,5 +1,5 @@
-/* xkeycaps, Copyright (c) 1991, 1992, 1993, 1994, 1997
- * by Jamie Zawinski <jwz@netscape.com>
+/* xkeycaps, Copyright (c) 1991, 1992, 1993, 1994, 1997, 1998
+ * by Jamie Zawinski <jwz@jwz.org>
  *
  * Permission to use, copy, modify, distribute, and sell this software and its
  * documentation for any purpose is hereby granted without fee, provided that
@@ -300,7 +300,7 @@ open_output_file(KeyboardWidget widget, char **name)
 #else /* ! __STDC__ */
 open_output_file(widget, name)
      KeyboardWidget widget;
-     char *name;
+     char **name;
 #endif /* ! __STDC__ */
 {
   const char *home = getenv("HOME");
@@ -561,7 +561,7 @@ button_write (button, client_data, call_data)
   if (userid)
     fprintf (out, " by %s", userid);
   fprintf (out, " with\n! %s.\n", short_version);
-  fprintf (out, "! http://people.netscape.com/jwz/xkeycaps/\n");
+  fprintf (out, "! http://www.jwz.org/xkeycaps/\n");
   fprintf (out, "!\n");
 
   if (partial && any_mod_changes)
