@@ -1,5 +1,5 @@
-/* xkeycaps, Copyright (c) 1991, 1992, 1993, 1995, 1996, 1997 
- * Jamie Zawinski <jwz@netscape.com>
+/* xkeycaps, Copyright (c) 1991, 1992, 1993, 1995, 1996, 1997, 1998 
+ * Jamie Zawinski <jwz@jwz.org>
  *
  * Permission to use, copy, modify, distribute, and sell this software and its
  * documentation for any purpose is hereby granted without fee, provided that
@@ -211,7 +211,7 @@ xkeycaps_main_loop (keyboard, app)
     }
 }
 
-void
+int
 #ifdef __STDC__
 main (int argc, char **argv)
 #else /* ! __STDC__ */
@@ -276,7 +276,7 @@ main (argc, argv)
 	or use the `Select Keyboard' dialog box.  Use the -help\n\
 	option to list recognised arguments to -kbd.  See the man\n\
 	page for more details.\n\n\
-	For updates, check http://www.netscape.com/people/jwz/xkeycaps/\n\n");
+	For updates, check http://www.jwz.org/xkeycaps/\n\n");
 
       if (!ok)
 	{
